@@ -180,6 +180,9 @@ static parsertab hdlc_par[] = {{ "no-parity", PARITY_NONE },
 
 static parsertab lmi[] = {{ "none", LMI_NONE },
 			  { "ansi", LMI_ANSI },
+#ifdef LMI_CISCO
+			  { "cisco", LMI_CISCO },
+#endif
 			  { "ccitt", LMI_CCITT },
 			  { NULL, 0 }};
 
@@ -563,6 +566,9 @@ static void show_port(void)
 			printf("protocol fr lmi %s",
 			       tabstr(fr->lmi, lmi, "unknown"));
 			if (fr->lmi == LMI_ANSI ||
+#ifdef LMI_CISCO
+			    fr->lmi == LMI_CISCO ||
+#endif
 			    fr->lmi == LMI_CCITT)
 				printf("%s t391 %u t392 %u n391 %u n392 %u "
 				       "n393 %u\n",
@@ -629,8 +635,8 @@ static void show_port(void)
 
 static void usage(void)
 {
-	fprintf(stderr, "sethdlc version 1.16\n"
-		"Copyright (C) 2000 - 2004 Krzysztof Halasa <khc@pm.waw.pl>\n"
+	fprintf(stderr, "sethdlc version 1.18\n"
+		"Copyright (C) 2000 - 2005 Krzysztof Halasa <khc@pm.waw.pl>\n"
 		"\n"
 		"Usage: sethdlc INTERFACE [PHYSICAL] [clock CLOCK] [LOOPBACK] "
 		"[slotmap SLOTMAP]\n"
@@ -657,7 +663,11 @@ static void usage(void)
 		"\n"
 		"ENCODING := nrz | nrzi | fm-mark | fm-space | manchester\n"
 		"PARITY := no-parity | crc16 | crc16-pr0 | crc16-itu | crc16-itu-pr0 | crc32-itu\n"
-		"LMI := none | ansi [LMI_SPEC] | ccitt [LMI_SPEC]\n"
+		"LMI := none | (ansi | ccitt"
+#ifdef LMI_CISCO
+		" | cisco"
+#endif
+		") [LMI_SPEC]\n"
 		"LMI_SPEC := [dce] [t391 val] [t392 val] [n391 val] [n392 val] [n393 val]\n");
 	exit(0);
 }
